==> html-pdf-js-0.0.1.tgz: package/index.js <==
const puppeteer = require('puppeteer');

const pdfGenerater = {

    pdfGenerater: async (pdfPath = '', htmlTemplate = null,) => {
        return new Promise(async (resolve, reject) => {
            try {
                if(!pdfPath){
                    throw new Error(`Please provide pdf save path`);
                }
                if(!htmlTemplate){
                    throw new Error(`Please provide html code to generate PDF.`);
                }
                console.log('pdfPath :', pdfPath);
                console.log('htmlTemplate :', htmlTemplate);
                // const browser = await puppeteer.launch();
                const browser = await puppeteer.launch({
                    headless: "new", // Ensure headless mode is used
                    args: [
                        '--no-sandbox', // Disables sandboxing for compatibility with certain servers
                        '--disable-setuid-sandbox', // Prevents privilege escalation issues
                        '--disable-dev-shm-usage', // Avoids shared memory issues
                        '--disable-accelerated-2d-canvas', // Optimizes performance
                        '--no-first-run', // Avoids unnecessary initial configurations
                        '--no-zygote', // Disables zygote process creation
                        '--single-process', // Runs Chromium as a single process
                        '--disable-gpu' // Ensures compatibility with non-GPU environments
                    ],
                });
                const page = await browser.newPage();
                await page.setContent(htmlTemplate, { waitUntil: 'networkidle0' });
                await page.pdf({
                    path: pdfPath,
                    format: 'A4',
                    margin: {
                        top: '0in',
                        bottom: '0in',
                        left: '0in',
                        right: '0in'
                    }
                });
                await browser.close();
                resolve(pdfPath);
            } catch (e) {
                console.error('error in pdfGenerater function =-=-==----->>>    ', e);
                reject(e);
            }
        });
    },

};

module.exports = pdfGenerater;

==> html-pdf-js-0.0.7.tgz: package/index.js <==
const puppeteer = require('puppeteer');

const pdfGenerater = {

    htmlToPdf: async (pdfPath = '', htmlTemplate = null, options = {}) => {
        const { format = 'A4', margin = { top: '0in', bottom: '0in', left: '0in', right: '0in' }, waitUntil = 'networkidle0', } = options;
        return new Promise(async (resolve, reject) => {
            try {
                if (!pdfPath) {
                    throw new Error(`Please provide pdf save path`);
                }
                if (!htmlTemplate) {
                    throw new Error(`Please provide html code to generate PDF.`);
                }
                
                console.log('pdfPath :', pdfPath);
                console.log('htmlTemplate :', htmlTemplate);
                // const browser = await puppeteer.launch();
                const browser = await puppeteer.launch({
                    headless: 'new', // Ensure headless mode is used
                    // headless: true,
                    args: [
                        '--no-sandbox', // Disables sandboxing for compatibility with certain servers
                        '--disable-setuid-sandbox', // Prevents privilege escalation issues
                        '--disable-dev-shm-usage', // Avoids shared memory issues
                        '--disable-accelerated-2d-canvas', // Optimizes performance
                        '--no-first-run', // Avoids unnecessary initial configurations
                        '--no-zygote', // Disables zygote process creation
                        '--single-process', // Runs Chromium as a single process
                        '--disable-gpu' // Ensures compatibility with non-GPU environments
                    ],
                });
                const page = await browser.newPage();
                await page.setContent(htmlTemplate, { waitUntil });
                await page.pdf({
                    path: pdfPath,
                    format,
                    margin
                });
                await browser.close();
                resolve(pdfPath);
            } catch (e) {
                console.error('error in pdfGenerater function =-=-==----->>>    ', e);
                reject(e);
            }
        });
    },

};

module.exports = pdfGenerater;
